#
# spec file for package hiredis
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global libname lib%{name}0_13
Name:           hiredis
Version:        0.13.3
Release:        bp154.2.55
Summary:        Minimalistic C client for Redis
License:        BSD-3-Clause
Group:          Productivity/Databases/Clients
Url:            https://github.com/redis/hiredis
Source0:        https://github.com/redis/hiredis/archive/v%{version}.tar.gz
Patch0:         CVE-2021-32765.patch
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Hiredis is a minimalistic C client library for the
[Redis](http://redis.io/) database.

%package devel
Summary:        Header files and libraries for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
The %{name}-devel package contains the header files and
libraries for Redis database.

%package -n %{libname}
Summary:        Shared library for %{name}
Group:          Productivity/Databases/Clients

%description -n %{libname}
Shared library for %{name}. The %{name}-example and
%{name}-test are in %{name} package.

%prep
%setup -q
%patch0 -p1

%build
make %{?_smp_mflags} OPTIMIZATION="%{optflags}" PREFIX=%{_prefix} LIBRARY_PATH=%{_lib}

%install
make install DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBRARY_PATH=%{_lib}

mkdir -p %{buildroot}%{_bindir}
install -m 0755 %{name}-* %{buildroot}%{_bindir}

find %{buildroot} -type f -name '*.a' -delete

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(0644,root,root,0755)
%doc COPYING README.md
%attr(0755,root,root) %{_bindir}/%{name}-*

%files devel
%defattr(0644,root,root,0755)
%doc CHANGELOG.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/hiredis.pc

%files -n %{libname}
%defattr(0755,root,root,0755)
%{_libdir}/lib%{name}.so.*

%changelog
* Tue Nov 23 2021 Andreas Stieger <andreas.stieger@gmx.de>
- Fix integer/buffer overflow CVE-2021-32765 boo#1191331
  add CVE-2021-32765.patch
* Sun Nov 22 2015 mpluskal@suse.com
- Update to 0.13.3
  * Revert "Clear `REDIS_CONNECTED` flag when connection is
  closed".
  * Make tests pass on FreeBSD
- Changes for 0.13.2
  * Prevent crash on pending replies in async code
  * Clear `REDIS_CONNECTED` flag when connection is closed
  * Add MacOS X addapter
  * Add Qt adapter
  * Add Ivykis adapter
- Changes for 0.13.1
  * Fix memory leak in async reply handling
  * Rename struct member to avoid name clash with pre-c99 code
- Changes for 0.13.0
  * Windows compatibility layer for parser code
  * Properly escape data printed to PKGCONF file
  * Fix tests when assert() undefined
  * Implement a reconnect method for the client context, this
  changes the structure of `redisContext`
- Drop hiredis-pkgconfig.patch
  * fixed in upstream
* Tue Mar  3 2015 dimstar@opensuse.org
- Add hiredis-pkgconfig.patch: Fix generation of .pc file.
- Pass PREFIX and LIBRARY_PATH (lib/lib64) to make (and make
  install): the build phase needs this info for the .pc file
  generation.
- Make use of the new DESTDIR support.
* Mon Mar  2 2015 mpluskal@suse.com
- Update to 0.12.1
  * Fix `make install`: DESTDIR support, install all required
    files, install PKGCONF in proper location
  * Fix `make test` as 32 bit build on 64 bit platform
- Changes for  0.12.0
  * Add optional KeepAlive support
  * Try again on EINTR errors
  * Add libuv adapter
  * Add IPv6 support
  * Remove possiblity of multiple close on same fd
  * Add ability to bind source address on connect
  * Add redisConnectFd() and redisFreeKeepFd()
  * Fix getaddrinfo() memory leak
  * Free string if it is unused (fixes memory leak)
  * Improve redisAppendCommandArgv performance 2.5x
  * Add support for SO_REUSEADDR
  * Fix redisvFormatCommand format parsing
  * Add GLib 2.0 adapter
  * Refactor reading code into read.c
  * Fix errno error buffers to not clobber errors
  * Generate pkgconf during build
  * Silence _BSD_SOURCE warnings
  * Improve digit counting for multibulk creation
* Tue Aug 20 2013 mvyskocil@suse.com
- Package hiredis 0.11.0 for openSUSE
